@@ -41,7 +41,7 @@ class SqlTableLoader(DataFrameLoader):
     @classmethod
     def load(
         cls,
-        uri: str,
+        connection_uri: str,
         table: str,
         use_dask: bool = False,
         index_column: Optional[str] = None,
@@ -54,7 +54,7 @@ class SqlTableLoader(DataFrameLoader):
         # Read the sql table using the sqlalchemy uri
         df = framework.read_sql_table(
             table,
-            uri,
+            connection_uri,
             index_col=index_column,
         )
 
